DataMart Python Wrapper for NYU's Datamart API
==============================================

This is a specialization of the Datamart REST API wrapper for NYU's system. It provides some optimization, running some computations locally rather than relying on the API server for everything.

See also the `generic datamart-rest wrapper <https://pypi.org/project/datamart-rest/>`__, and the `REST API documentation <https://datadrivendiscovery.gitlab.io/datamart-api/rest_api.html>`__.

How to install?
---------------

::

    $ pip install datamart-nyu

How to use?
-----------

We provide an example using the `NY Taxi Demand data <https://gitlab.datadrivendiscovery.org/d3m/datasets/tree/master/seed_datasets_data_augmentation/DA_ny_taxi_demand/DA_ny_taxi_demand_dataset>`__. The example is available `here <examples/ny-taxi-demand.ipynb>`__.
